web_plat/webutils_api/inc/WebUtilsInternalCRKeys.h
branchRCL_3
changeset 94 919f36ff910f
parent 93 79859ed3eea9
--- a/web_plat/webutils_api/inc/WebUtilsInternalCRKeys.h	Tue Aug 31 16:17:46 2010 +0300
+++ b/web_plat/webutils_api/inc/WebUtilsInternalCRKeys.h	Wed Sep 01 12:28:30 2010 +0100
@@ -18,8 +18,6 @@
 #ifndef WEBUTILSINTERNALCRKEYS_H
 #define WEBUTILSINTERNALCRKEYS_H
 
-#warning The Web Utils API will be removed wk25. Please see http://wikis.in.nokia.com/Browser/APIMigration for more information
-
 #include <WebUtilsSDKCRKeys.h>
 
 // AppName fragment of useragent string
@@ -73,8 +71,8 @@
 // Browser Version Minor
 const TUint32 KWebUtilsBrowserVersionMinor =	0x00000010;
 
-// Browser Version SVN Rev 
-const TUint32 KWebUtilsBrowserVersionSVNRev =	0x00000011;
+// Browser Version Feature Rev 
+const TUint32 KWebUtilsBrowserVersionFeatureRev =	0x00000011;
 
 // Browser Name
 const TUint32 KWebUtilsBrowserName =	0x00000012;
@@ -82,5 +80,7 @@
 // Ignore product program config when TRUE 
 const TUint32 KWebUtilsIgnoreConfig =	0x00000013;
 
+// Browser Version Patch Rev 
+const TUint32 KWebUtilsBrowserVersionPatchRev =	0x00000014;
 		
 #endif // WEBUTILSINTERNALCRKEYS_H